@@ -1,4 +1,4 @@
-from abstract_utilities import convert_to_percentage,read_from_file
+from abstract_utilities import convert_to_percentage,read_from_file,eatAll
 from abstract_utilities.type_utils import is_number
 from ..instruction_selection.InstructionBuilder import InstructionManager
 from ..model_selection.ModelBuilder import ModelManager
@@ -64,7 +64,7 @@ class PromptManager:
                                                                          completion_percentage=self.completion_percentage,
                                                                          prompt_data=self.prompt_data)
         
-
+        
     def calculate_token_distribution(self,
                                      request=None,
                                      notation=None,
@@ -149,7 +149,7 @@ class PromptManager:
             """
             # Function implementation ...
             get_token_distributions = []
-            data_chunks_list = chunk_data_by_type(total_chunk_data, fictitious_chunk_token_length,chunk_type)
+            data_chunks_list = chunk_source_code(total_chunk_data, fictitious_chunk_token_length)
             total_chunks = len(data_chunks_list)
 
             for i, chunk_data in enumerate(data_chunks_list):
@@ -175,47 +175,45 @@ class PromptManager:
 
             return get_token_distributions
         token_distributions=[]
-        try:
-            for i,chunk_prompt in enumerate(prompt_data):
-                tokenize_js={"notation":notation,
-                    "max_tokens":max_tokens,
-                    "completion_percentage":completion_percentage,
-                    "prompt_guide":self.create_prompt_guide(request=request[i],chunk_token_distribution_number=i),
-                    "chunk_prompt":chunk_prompt}
-                total_prompt = ''
-                for each in tokenize_js.keys():
-                    if each != "chunk_prompt":
-                        total_prompt+=str(tokenize_js[each])
-                        
-                max_tokens = int(tokenize_js["max_tokens"])
-                
-                completion_percent = convert_to_percentage(tokenize_js["completion_percentage"])
-                completion_token_desired = int(max_tokens*completion_percent)
-                
-                
-                prompt_percent = convert_to_percentage(100-tokenize_js["completion_percentage"])
-                prompt_token_desired = int(max_tokens*prompt_percent)
-                bot_notation_token_count=int(200)
-                initial_prompt_token_length = num_tokens_from_string(str(total_prompt))+bot_notation_token_count
-
-                initial_completion_token_length=bot_notation_token_count
-                
-                total_chunk_data = tokenize_js["chunk_prompt"] or ''
+        for i,chunk_prompt in enumerate(prompt_data):
+            tokenize_js={"notation":notation,
+                "max_tokens":max_tokens,
+                "completion_percentage":completion_percentage,
+                "prompt_guide":self.create_prompt_guide(request=request[i],chunk_token_distribution_number=i),
+                "chunk_prompt":chunk_prompt}
+            total_prompt = ''
+            for each in tokenize_js.keys():
+                if each != "chunk_prompt":
+                    total_prompt+=str(tokenize_js[each])
+                    
+            max_tokens = int(tokenize_js["max_tokens"])
             
-                total_chunk_token_length = num_tokens_from_string(str(total_chunk_data))
-                ficticious_chunk_token_length = prompt_token_desired-initial_prompt_token_length
-                num_chunks = total_chunk_token_length // ficticious_chunk_token_length      
-                instruction_token_size = 0
-                
-                token_distributions.append(get_token_distributions(prompt_token_desired=prompt_token_desired,
-                                                             initial_prompt_token_length=initial_prompt_token_length,
-                                                             total_chunk_data=total_chunk_data,
-                                                             fictitious_chunk_token_length=ficticious_chunk_token_length,
-                                                             completion_token_desired=completion_token_desired,
-                                                             initial_completion_token_length=initial_completion_token_length,
-                                                             chunk_type=self.chunk_type))
-        except:
-            pass
+            completion_percent = convert_to_percentage(tokenize_js["completion_percentage"])
+            completion_token_desired = int(max_tokens*completion_percent)
+            
+            
+            prompt_percent = convert_to_percentage(100-tokenize_js["completion_percentage"])
+            prompt_token_desired = int(max_tokens*prompt_percent)
+            bot_notation_token_count=int(200)
+            initial_prompt_token_length = num_tokens_from_string(str(total_prompt))+bot_notation_token_count
+
+            initial_completion_token_length=bot_notation_token_count
+            
+            total_chunk_data = tokenize_js["chunk_prompt"] or ''
+        
+            total_chunk_token_length = num_tokens_from_string(str(total_chunk_data))
+            ficticious_chunk_token_length = prompt_token_desired-initial_prompt_token_length
+            num_chunks = total_chunk_token_length // ficticious_chunk_token_length      
+            instruction_token_size = 0
+            
+            token_distributions.append(get_token_distributions(prompt_token_desired=prompt_token_desired,
+                                                         initial_prompt_token_length=initial_prompt_token_length,
+                                                         total_chunk_data=total_chunk_data,
+                                                         fictitious_chunk_token_length=ficticious_chunk_token_length,
+                                                         completion_token_desired=completion_token_desired,
+                                                         initial_completion_token_length=initial_completion_token_length,
+                                                         chunk_type=self.chunk_type))
+       
         return token_distributions
             
     def create_prompt_guide(self,
@@ -254,7 +252,9 @@ class PromptManager:
                 return f'#{title}#'+'\n\n'+f'{data}'
             return ''
         def get_chunk_header(current_chunk,total_chunks,chunk_data):
-            if total_chunks in [0,'0']:
+    
+            if total_chunks in [0,'0'] or eatAll(chunk_data,['\n','\t',' ','']) in['',None]:
+                
                 return None
             current_chunk = current_chunk or 0
             try:
@@ -268,7 +268,7 @@ class PromptManager:
             chunk_number=0
             total_chunks =10
             chunk_data= ''
-        
+            
         request = request or self.request[chunk_token_distribution_number]
         values_js = {'instructions':{'display':'instructions','data':instructions or self.instructions},
                      'request_chunks':{'display':'previous chunk data requested','data':prompt_as_previous},
@@ -279,10 +279,14 @@ class PromptManager:
                      'generate_title':{'display':'previously generated_title','data':generate_title}
                      }
         prompt_data_source = ''
+        self.key_check=[]
         for key,value in values_js.items():
             title = value['display']
             data = value['data']
             if data:
+                self.key_check.append(key)
+                if key == 'chunk_data':
+                    self.last_chunk = value['data']
                 prompt_data_source+=f"{get_delimeters()}{get_for_prompt(title,data)}"
         return prompt_data_source
 
@@ -328,5 +332,9 @@ class PromptManager:
                                               prompt_as_previous=prompt_as_previous)
         max_tokens = chunk_token_distribution_data['completion']['available']
         self.prompt ={"model": self.model_mgr.selected_model_name, "messages": [{"role": self.role or "user", "content":self.prompt }],"max_tokens": max_tokens}
+        for each in self.key_check:
+            if each not in ['instructions']:
+                break
+            self.prompt['blank_prompt']=True
         return self.prompt
 
