@@ -188,7 +188,6 @@ class ResponseManager:
         Handles the response after a query has been sent.
         """
         self.query_js={}
-       
         self.prompt = self.prompt_mgr.create_prompt(chunk_token_distribution_number=self.chunk_token_distribution_number,
                                                     chunk_number = self.chunk_number,
                                                     notation=self.notation,
@@ -196,11 +195,12 @@ class ResponseManager:
                                                     request_chunks=self.request_chunks,
                                                     token_adjustment=self.token_adjustment,
                                                     prompt_as_previous=self.prompt_as_previous_clone)
-        self.query_js["prompt"]=safe_json_loads(self.prompt)
-        self.endpoint = self.model_mgr.selected_endpoint
-        self.header = self.api_mgr.header
-        self.response = requests.post(url=self.endpoint, json=self.prompt, headers=self.header)
-        safe_json_loads(self.get_response())
+        if self.prompt.get('blank_prompt')==None:
+            self.query_js["prompt"]=safe_json_loads(self.prompt)
+            self.endpoint = self.model_mgr.selected_endpoint
+            self.header = self.api_mgr.header
+            self.response = requests.post(url=self.endpoint, json=self.prompt, headers=self.header)
+            safe_json_loads(self.get_response())
     def initial_query(self):
         """
         Manages the initial sequence of sending queries and processing responses.
@@ -222,14 +222,13 @@ class ResponseManager:
                 abort_it=False
                 while response_loop:
                     self.send_query()
-                    if self.get_abort() or self.abort_js["abort"]:
+                    if self.get_abort() or self.abort_js["abort"] or self.prompt.get('blank_prompt'):
                         response_loop=False
                         break
                 print(f'in while {self.i_query}')
                 if self.abort_js["abort"]:
                     break
                 self.i_query+=1
-                
         self.query_done=True
         self.i_query=0
         return self.output
